package ru.myitschool.work.ui.login

import ru.myitschool.work.api.ApiService
import android.util.Log
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class LoginViewModel @Inject constructor(
    private val apiService: ApiService
) : ViewModel() {

    private val _state = MutableStateFlow(LoginState())
    val state: StateFlow<LoginState> get() = _state

    fun authenticate(username: String, password: String) {
        if (isValidUsername(username)) {
            viewModelScope.launch {
                try {
                    val response = apiService.authenticate(username, password)
                    Log.d("LoginViewModel", "Response code: ${response.code()}")

                    // Проверяем код ответа
                    when (response.code()) {
                        200 -> {
                            _state.value = LoginState(success = true) // Успешная авторизация
                        }
                        400 -> {
                            _state.value = LoginState(error = "Ошибка авторизации: Неверные учетные данные.")
                        }
                        else -> {
                            _state.value = LoginState(error = "Ошибка авторизации: ${response.message()}")
                        }
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                    _state.value = LoginState(error = "Ошибка сети. Проверьте подключение к интернету.")
                }
            }
        } else {
            _state.value = LoginState(error = "Неправильный логин")
        }
    }

    private fun isValidUsername(username: String): Boolean {
        return username.isNotEmpty() // Пример проверки логина
    }
}

// Состояние аутентификации
data class LoginState(
    val success: Boolean = false, // Успешность аутентификации
    val error: String? = null, // Сообщение об ошибке
    val maintenance: Boolean = false // Состояние техобслуживания
)